# ROI Tool

ROI Tool selects Regions Of Interest and culculates a sum of their pixel intensities

- ROI alias(es) for roi tango devices
- Add to or Fetch from sardana environment. If lavue is working with ANALYSISDEVICE , i.e. lavue -n <device>, ROIs bounds are sending also to tango SPECTRUM RoIs attribute of the device, e.g. LambdaOnlineAnalysis server.
- Sum of the selected ROI or all ROIs. The used version can be selected in the configuration.

Moreover, in configuration can be set if the sums of calculated ROIs should be sent to LavueController tango server.